"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ContractWallet = void 0;
const ton3_core_1 = require("ton3-core");
class ContractWallet extends ton3_core_1.Contracts.ContractBase {
    constructor(code, workchain, publicKey, subwalletId = 0) {
        const storage = new ton3_core_1.Builder()
            .storeUint(0, 32)
            .storeUint(subwalletId, 32)
            .storeBytes(publicKey)
            .cell();
        super(workchain, code, storage);
        this.publicKey = publicKey;
        this.subwalletId = subwalletId;
    }
    createTransferMessage(transfers, seqno, timeout = 60) {
        if (!transfers.length || transfers.length > 4) {
            throw new Error('ContractWalletV3: can make only 1 to 4 transfers per operation.');
        }
        const body = new ton3_core_1.Builder()
            .storeUint(this.subwalletId, 32)
            .storeUint(~~(Date.now() / 1000) + timeout, 32)
            .storeUint(seqno, 32);
        transfers.forEach((transfer) => {
            const internal = new ton3_core_1.Contracts.MessageInternal({
                bounce: transfer.destination.bounceable,
                src: ton3_core_1.Address.NONE,
                dest: transfer.destination,
                value: transfer.amount
            }, { body: transfer.body, state: transfer.init });
            body.storeUint(transfer.mode, 8).storeRef(internal.cell());
        });
        return new ton3_core_1.Contracts.MessageExternalIn({ dest: this.address }, { body: body.cell(), state: seqno === 0 ? this.state : null });
    }
    createDeployMessage() {
        const body = new ton3_core_1.Builder()
            .storeUint(this.subwalletId, 32)
            .storeInt(-1, 32)
            .storeUint(0, 32);
        return new ton3_core_1.Contracts.MessageExternalIn({ dest: this.address }, { body: body.cell(), state: this.state });
    }
}
exports.ContractWallet = ContractWallet;
//# sourceMappingURL=wallet.js.map